@@ -31,6 +31,7 @@
 #'     \item{"basic"}{Normalized ranks vs. accuracy, error rate, specificity,
 #'                    sensitivity, precision, Matthews correlation coefficient,
 #'                    and F-score. }
+#'     \item{"aucroc"}{Fast AUC(ROC) calculation with the U statistic}
 #'   }
 #'
 #' @param scores A numeric dataset of predicted scores. It can be a vector,
@@ -60,8 +61,8 @@
 #' @param na_worst A Boolean value for controlling the treatment of NAs
 #'   in \code{scores}.
 #'   \describe{
-#'     \item{TRUE}{NAs are treated as the highest score}
-#'     \item{FALSE}{NAs are treated as the lowest score}
+#'     \item{TRUE}{All NAs are treated as the worst scores}
+#'     \item{FALSE}{All NAs are treated as the best scores}
 #'   }
 #'
 #' @param ties_method A string for controlling ties in \code{scores}.
@@ -95,6 +96,8 @@
 #'   and \code{x_bins = 4}, respectively. All corresponding y-values of
 #'   the supporting points are calculated.
 #'
+#' @param ... Not used by this method.
+#'
 #' @return The \code{evalmod} function returns an \code{S3} object
 #'   that contains performance evaluation measures. The number of models and
 #'   the number of datasets can be controlled by \code{modnames} and
@@ -102,6 +105,10 @@
 #'   of test datasets is "multiple" when \code{modnames = c("m1", "m1", "m1")}
 #'   and \code{dsids = c(1, 2, 3)} are specified.
 #'
+#' Different \code{S3} objects have different default behaviors of \code{S3}
+#'   generics, such as \code{\link{plot}}, \code{\link{autoplot}}, and
+#'   \code{\link{fortify}}.
+#'
 #' \enumerate{
 #'
 #'   \item  The \code{evalmod} function returns one of the following \code{S3}
@@ -134,11 +141,11 @@
 #'     smpoints \tab single   \tab multiple \cr
 #'     mmpoints \tab multiple \tab multiple
 #'   }
-#' }
 #'
-#' Different \code{S3} objects have different default behaviors of \code{S3}
-#'   generics, such as \code{\link{plot}}, \code{\link{autoplot}}, and
-#'   \code{\link{fortify}}.
+#'   \item The \code{evalmod} function returns the \code{aucroc} S3 object
+#'   when \code{mode} is "aucroc", which can be used with 'print' and 'as.data.frame'.
+#'
+#' }
 #'
 #' @seealso \code{\link{plot}} for plotting curves with the general R plot.
 #'   \code{\link{autoplot}} and \code{\link{fortify}} for plotting curves
@@ -222,38 +229,111 @@
 #' mmpoints <- evalmod(mdat, mode = "basic")
 #' mmpoints
 #'
+#'
+#' ##################################################
+#' ### AUC with the U statistic
+#' ###
+#'
+#' ## mode = "aucroc" returns 'aucroc' S3 object
+#' data(P10N10)
+#'
+#' # 'aucroc' S3 object
+#' uauc1 <- evalmod(scores = P10N10$scores, labels = P10N10$labels,
+#'                  mode="aucroc")
+#'
+#' # print 'aucroc'
+#' uauc1
+#'
+#' # as.data.frame 'aucroc'
+#' as.data.frame(uauc1)
+#'
+#' ## It is 2-3 times faster than mode = "rocprc"
+#' # A sample of 100,000
+#' samp1 <- create_sim_samples(1, 50000, 50000)
+#'
+#' # a function to test mode = "rocprc"
+#' func_evalmod_rocprc <- function(samp) {
+#'    curves <- evalmod(scores = samp$scores, labels = samp$labels)
+#'    aucs <- auc(curves)
+#' }
+#'
+#' # a function to test mode = "aucroc"
+#' func_evalmod_aucroc <- function(samp) {
+#'   uaucs <- evalmod(scores = samp$scores, labels = samp$labels, mode="aucroc")
+#'   as.data.frame(uaucs)
+#' }
+#'
+#' # Process time
+#' system.time(res1 <- func_evalmod_rocprc(samp1))
+#' system.time(res2 <- func_evalmod_aucroc(samp1))
+#'
+#' # AUCs
+#' res1
+#' res2
+#'
 #' @export
-evalmod <- function(mdat, mode = "rocprc", scores = NULL, labels = NULL,
+evalmod <- function(mdat, mode = NULL, scores = NULL, labels = NULL,
                     modnames = NULL, dsids = NULL,
                     posclass = NULL, na_worst = TRUE, ties_method = "equiv",
                     calc_avg = TRUE, cb_alpha = 0.05, raw_curves = FALSE,
-                    x_bins = 1000) {
+                    x_bins = 1000, ...) {
 
   # Validation
-  new_mode <- .pmatch_mode(mode)
-  new_ties_method <- .pmatch_tiesmethod(ties_method)
+  new_mode <- .get_new_mode(mode, mdat, "rocprc")
+  new_ties_method <- .pmatch_tiesmethod(ties_method, ...)
+  new_na_worst <- .get_new_naworst(na_worst, ...)
   if (x_bins == 0) {
     x_bins <- 1
   }
-  .validate_evalmod_args(new_mode, modnames, dsids, posclass, na_worst,
+  .validate_evalmod_args(new_mode, modnames, dsids, posclass, new_na_worst,
                          new_ties_method, calc_avg, cb_alpha, raw_curves,
                          x_bins)
 
   # Create mdat if not provided
-  if (!missing(mdat)) {
-    .validate(mdat)
-  } else {
+  if (missing(mdat)) {
     mdat <- mmdata(scores, labels,
                    modnames = modnames, dsids = dsids, posclass = posclass,
-                   na_worst = na_worst, ties_method = new_ties_method)
+                   na_worst = new_na_worst, ties_method = new_ties_method,
+                   mode = new_mode)
   }
+  .validate(mdat)
 
   # Call pipeline controller
   pl_main(mdat, mode = new_mode, calc_avg = calc_avg, cb_alpha = cb_alpha,
-          raw_curves = raw_curves, x_bins = x_bins, validate = FALSE)
+          raw_curves = raw_curves, x_bins = x_bins, na_worst = new_na_worst,
+          ties_method = new_ties_method, validate = FALSE)
 
 }
 
+#
+# Get a mode
+#
+.get_new_mode <- function(mode, mdat, def_mode = "rocprc") {
+  mdat_mode <- NA
+  if (!missing(mdat)) {
+    .validate(mdat)
+    mdat_mode <- attr(mdat, "args")[["mode"]]
+  }
+
+  new_mode <- NA
+  if (!is.null(mode)) {
+    new_mode <- .pmatch_mode(mode)
+    if (new_mode != "aucroc" && !is.na(mdat_mode) &&  mdat_mode == "aucroc") {
+      stop(paste0("Invalid 'mode': evalmod <- '", new_mode,
+                  "'', mmdata <- '", mdat_mode, "'"),
+           call. = FALSE)
+    }
+  } else if (!is.na(mdat_mode)) {
+    new_mode <- mdat_mode
+  }
+
+  if (is.null(new_mode) || is.na(new_mode)) {
+    new_mode <- def_mode
+  }
+
+  new_mode
+}
+
 #
 # Validate arguments of evalmod()
 #
